#
# spec file for package liblnk
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           liblnk
%define lname	liblnk1
%define timestamp 	20150105
Version:        0~%timestamp
Release:        5.1
Summary:        Library and tools to access the Windows Shortcut File (LNK) format
License:        LGPL-3.0+ and GFDL-1.3+
Group:          Productivity/File utilities
Url:            https://github.com/libyal/liblnk/wiki
Source:         https://github.com/libyal/liblnk/releases/download/%timestamp/%name-alpha-%timestamp.tar.gz
Source2:        Windows_Shortcut_File_(LNK)_format.pdf
BuildRequires:  pkg-config
BuildRequires:  python-devel
BuildRequires:  pkgconfig(libbfio) >= 20130721
BuildRequires:  pkgconfig(libcdata) >= 20130904
BuildRequires:  pkgconfig(libcerror) >= 20140105
BuildRequires:  pkgconfig(libcfile) >= 20130609
BuildRequires:  pkgconfig(libclocale) >= 20130609
BuildRequires:  pkgconfig(libcnotify) >= 20130609
BuildRequires:  pkgconfig(libcpath) >= 20130609
BuildRequires:  pkgconfig(libcsplit) >= 20130609
BuildRequires:  pkgconfig(libcstring) >= 20120425
BuildRequires:  pkgconfig(libcsystem) >= 20120425
BuildRequires:  pkgconfig(libfdatetime) >= 20130317
BuildRequires:  pkgconfig(libfguid) >= 20130904
BuildRequires:  pkgconfig(libuna) >= 20120425
#BuildRequires:  pkgconfig(libfwsi) >= 20120426 (not yet stable per upstream 9/2014)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
liblnk is a library and tools to access Windows Shortcut File (LNK) format files.

%package -n %lname
Summary:        Library to access the Windows Shortcut File (LNK) format
License:        LGPL-3.0+
Group:          System/Libraries

%description -n %lname
liblnk is a library to access Windows Shortcut File (LNK) files.

%package tools
Summary:        Tools to access the Windows Shortcut File (LNK) format
License:        LGPL-3.0+
Group:          Productivity/File utilities

%description tools
liblnk is a library to access Windows Shortcut File (LNK) files.
 
%package devel
Summary:        Development files for liblnk, a library to access Windows Shortcut Links
License:        LGPL-3.0+ and GFDL-1.3+
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
liblnk is a library to access Windows Shortcut File (LNK) files.

This subpackage contains libraries and header files for developing
applications that want to make use of %name.

%package -n python-%name
Summary:        Python bindings for liblnk, a Windows Shortcut Link parser
License:        LGPL-3.0+
Group:          Development/Libraries/Python
Requires:       %lname = %version
Requires:       python
Provides:       pylnk = %version

%description -n python-%name
Python binding for liblnk, which can read Windows Shortcut Link files.

%prep
%setup -qn liblnk-%timestamp
cp "%SOURCE2" .

%build
%configure --disable-static --enable-wide-character-type --enable-python
make %{?_smp_mflags}

%install
make install DESTDIR="%buildroot"
find %buildroot -name '*.la' -delete

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog
%_libdir/liblnk.so.*

%files tools
%defattr(-,root,root)
%_bindir/lnk*
%_mandir/man1/lnkinfo.1*

%files devel
%defattr(-,root,root)
%doc Windows_Shortcut_File_*.pdf
%_includedir/liblnk.h
%_includedir/liblnk/
%_libdir/liblnk.so
%_libdir/pkgconfig/liblnk.pc
%_mandir/man3/liblnk.3*

%files -n python-%name
%defattr(-,root,root)
%doc AUTHORS COPYING README
%python_sitearch/pylnk.so

%changelog
* Tue Jan 13 2015 Greg.Freemyer@gmail.com
- update to v0~20150105
  * 2015 update
  * worked on Python 3 support
  * worked on tests
  * code clean up
- update source URL to point to new github site
- use new libyal packages from OBS instead of internal versions
* Mon Dec 22 2014 Greg.Freemyer@gmail.com
- update to v0~20141026
  * changes for deployment
  * worked on utility scripts
  * update Python-bindings tests
* Fri Sep 19 2014 Greg.Freemyer@gmail.com
- update to v0~20140905
  * bug fix in Python-bindings
  * worked on property store data block support
  * updated libfwsi version check
- change Source: field to fullpath, delete DL_URL
- use external libcerror package
* Tue Aug 26 2014 Greg.Freemyer@gmail.com
- add these 2 lines to python sub-project to ensure proper syncronization between versions
  * Requires:     %%lname = %%version
  * Provides:	pylnk = %%version
* Wed Aug 13 2014 Greg.Freemyer@gmail.com
- update to v0~20140731
  * bug fix in Python-bindings
  * worked on Python bindings
  - changes regarding integer object signedness on 32-bit architectures
  * worked on shell items support
  * small changes in debug output
  * small changes in lnkinfo output
  * updated dependencies
  * worked on updates
  * 2014 update
* Thu Nov 21 2013 Greg.Freemyer@gmail.com
- update to v0~20131015
  * updated dependencies
  * improved pyolecf as integer functions
  * worked on setup.py, largely for MSI builds
- cleanup BuildRequires statements
* Fri Sep 20 2013 Greg.Freemyer@gmail.com
- updated to v0~20130829
  * change to API to expose link target identifier data
  * fixes for building with stand-alone libuna and libbfio
  * updated dependencies
  * worked on automated tests
  * bug fix in pymsiecf file object libbfio glue code
  * worked on shell items
  - detection of delegate 0x2e item
  * fix in debug output for local path
  * worked on tests
  * textual changes
* Tue Jul 30 2013 Greg.Freemyer@gmail.com
- update to v0~20130413
  * updated dependencies
  * moved examples to project site
  * updated lnkinfo man page
  * worked on tests
  * updates and bug fixes in pylnk
  * fixed codepage 949, 950, 1255 restriction
  * added PackageMaker files
  * added functions to retrieve drive type, drive serial number and volume label
  * fix trailing \ for local and network path when common path is an emtpy string
- use gz compression to simplify download/convert
- use factory version of sub-packages as possible
* Fri Apr  5 2013 jengelh@inai.de
- Cleanups: Set RPM group, license, summary and description
  metadata; remove unused %%py_requires; do not bloat shlib package
  with documentation
- Use system libraries instead of bundled ones where possible
- Name the tools package according to upstream's recommendation
- Drop unnecessary -fno-strict-aliasing
- Drop Windows_Shell_Item pdf, this belongs to a different package
* Wed Mar 27 2013 Greg.Freemyer@gmail.com
- initial package (version 0~20130304) for build.opensuse.org
